@@ -222,12 +222,12 @@ durationstr(long secs, char *buf, size_t bufsiz)
 	return r;
 }
 
-/* print views with thousand separators */
-void
+/* print views with thousand separators, returns printed characters */
+size_t
 printnumsep(const char *s)
 {
 	const char *p;
-	int ndigits = 0;
+	size_t n = 0, ndigits = 0;
 
 	/* first count all digits */
 	for (p = s; *p; p++)
@@ -239,11 +239,16 @@ printnumsep(const char *s)
 			continue;
 
 		putchar(*p);
+		n++;
 		ndigits--;
 
 		/* show separator on every 3 digits and when there are
 		   digits remaining */
-		if ((ndigits % 3) == 0 && ndigits > 0)
+		if ((ndigits % 3) == 0 && ndigits > 0) {
 			putchar(',');
+			n++;
+		}
 	}
+
+	return n;
 }
