@@ -21,7 +21,7 @@ int friendlytime(time_t now, time_t t);
 char *getparam(const char *query, const char *s);
 void gophertext(FILE *fp, const char *s, size_t len);
 int hexdigit(int c);
-void printnumsep(const char *s);
+size_t printnumsep(const char *s);
 int uriencode(const char *s, char *buf, size_t bufsiz);
 int utf8pad(char *buf, size_t bufsiz, const char *s, size_t len, int pad);
 void xmlencode(const char *s);
