@@ -155,7 +155,7 @@ render_search(struct search_response *r)
 {
 	struct item *v;
 	int n;
-	size_t i;
+	size_t i, len;
 
 	if (pledge("stdio", NULL) == -1) {
 		OUT("Status: 500 Internal Server Error\r\n\r\n");
@@ -212,6 +212,9 @@ render_search(struct search_response *r)
 				OUT(">");
 			}
 
+			if (v->membersonly)
+				xmlencode(MEMBERS_ONLY);
+
 			switch (v->linktype) {
 			case Channel:
 				OUT("[Channel] ");
@@ -281,9 +284,13 @@ render_search(struct search_response *r)
 				OUT("</span><br/>\n");
 			}
 			OUT("		<span class=\"stats\">");
-			printnumsep(v->viewcount);
+			if (v->viewcount[0]) {
+				if (!printnumsep(v->viewcount))
+					OUT("0");
+				OUT(" views");
+			}
 			OUT(
-				" views</span><br/>\n"
+				"</span><br/>\n"
 				"	</td>\n"
 				"	<td align=\"right\" class=\"a-r\">\n"
 				"		<span class=\"duration\">");
@@ -348,6 +355,17 @@ render_video(struct video_response *r)
 		OUT("</td></tr>\n");
 	}
 
+	/* show playability state and reason: for example when it is a members-only video */
+	if (r->playabilityreason[0]) {
+		OUT("<tr><td><b>Status:</b></td><td><b>");
+		if (r->playabilitystatus[0]) {
+			OUT(r->playabilitystatus);
+			OUT(": ");
+		}
+		OUT(r->playabilityreason);
+		OUT("</b></td></tr>\n");
+	}
+
 	if (r->author[0]) {
 		OUT("<tr><td><b>Channel:</b></td><td>");
 		if (r->channelid[0]) {
@@ -367,7 +385,8 @@ render_video(struct video_response *r)
 
 	OUT("<tr><td><b>Views:</b></td><td>");
 	snprintf(buf, sizeof(buf), "%ld", r->viewcount);
-	printnumsep(buf);
+	if (!printnumsep(buf))
+		OUT("0");
 	OUT("</td></tr>\n");
 
 	if (r->publishdate[0]) {
