@@ -460,6 +460,8 @@ atom_item(void)
 		return;
 
 	fputs("<entry>\n\t<title>", stdout);
+	if (found->membersonly)
+		xmlencode(MEMBERS_ONLY);
 	xmlencode(ctx.fields[FeedFieldTitle].str.data);
 	if (found->duration[0]) {
 		fputs(" [", stdout);
@@ -546,8 +548,9 @@ html_item(void)
 		fputs("\">", stdout);
 	}
 
+	if (found->membersonly)
+		xmlencode(MEMBERS_ONLY);
 	xmlencode(ctx.fields[FeedFieldTitle].str.data);
-
 	if (found->duration[0]) {
 		fputs(" [", stdout);
 		xmlencode(found->duration);
@@ -600,6 +603,8 @@ gph_item(void)
 	/* just print the original timestamp, it should conform */
 	gphencode(ctx.fields[FeedFieldTime].str.data);
 	fputs(" ", stdout);
+	if (found->membersonly)
+		gphencode(MEMBERS_ONLY);
 	gphencode(ctx.fields[FeedFieldTitle].str.data);
 	if (found->duration[0]) {
 		fputs(" [", stdout);
@@ -679,6 +684,8 @@ json_item(void)
 	fputs("\"", stdout);
 
 	fputs(",\n\t\"title\": \"", stdout);
+	if (found->membersonly)
+		json_printfield(MEMBERS_ONLY);
 	json_printfield(ctx.fields[FeedFieldTitle].str.data);
 	if (found->duration[0]) {
 		fputs(" [", stdout);
@@ -726,6 +733,8 @@ sfeed_item(void)
 
 	string_print_timestamp(&ctx.fields[FeedFieldTime].str);
 	putchar(FieldSeparator);
+	if (found->membersonly)
+		fputs(MEMBERS_ONLY, stdout);
 	string_print(&ctx.fields[FeedFieldTitle].str);
 	if (found->duration[0]) {
 		fputs(" [", stdout);
@@ -771,6 +780,8 @@ twtxt_item(void)
 
 	string_print(&ctx.fields[FeedFieldTime].str);
 	putchar(FieldSeparator);
+	if (found->membersonly)
+		fputs(MEMBERS_ONLY, stdout);
 	string_print(&ctx.fields[FeedFieldTitle].str);
 	if (found->duration[0]) {
 		fputs(" [", stdout);
@@ -1038,16 +1049,18 @@ isvalidchannel(const char *s)
 void
 usage(void)
 {
-	const char *msg = "Bad Request, path should be the channel id + file extension, for example: UCrbvoMC0zUvPL8vjswhLOSw.json";
+	const char *line1 = "Bad Request, path should be the channel id + file extension, for example: UCrbvoMC0zUvPL8vjswhLOSw.json";
+	const char *line2 = "Supported extensions are: [atom|gph|html|json|tsv|txt]";
 
 	if (cgimode) {
 		if (godmode) {
-			printf("3%s\tErr\t%s\t%s\r\n", msg, server_name, server_port);
+			printf("3%s\tErr\t%s\t%s\r\n", line1, server_name, server_port);
+			printf("3%s\tErr\t%s\t%s\r\n", line2, server_name, server_port);
 		} else {
 			fputs("Status: 400 Bad Request\r\n", stdout);
 			fputs("Content-Type: text/plain; charset=utf-8\r\n\r\n", stdout);
-			printf("400 %s\n", msg);
-			fputs("Supported extensions are: [atom|gph|html|json|tsv|txt]\n", stdout);
+			printf("400 %s\n", line1);
+			printf("\n%s", line2);
 		}
 		exit(0);
 	} else {
@@ -1075,6 +1088,14 @@ main(int argc, char *argv[])
 
 	if (path) {
 		cgimode = 1;
+
+		if ((tmp = getenv("SERVER_NAME")))
+			server_name = tmp;
+		if ((tmp = getenv("SERVER_PORT")))
+			server_port = tmp;
+		if ((tmp = getenv("SERVER_PROTOCOL")) && strstr(tmp, "gopher"))
+			godmode = 1;
+
 		strlcpy(buf, path, sizeof(buf));
 		path = buf;
 
@@ -1086,12 +1107,6 @@ main(int argc, char *argv[])
 			*p = '\0'; /* NULL terminate */
 			format = p + 1;
 		}
-		if ((tmp = getenv("SERVER_NAME")))
-			server_name = tmp;
-		if ((tmp = getenv("SERVER_PORT")))
-			server_port = tmp;
-		if ((tmp = getenv("SERVER_PROTOCOL")) && strstr(tmp, "gopher"))
-			godmode = 1;
 	} else {
 		if (argc <= 1)
 			usage();
