@@ -76,6 +76,9 @@ render_search(struct search_response *r)
 		else
 			putchar('i');
 
+		if (v->membersonly)
+			OUTTEXT(MEMBERS_ONLY);
+
 		switch (v->linktype) {
 		case Channel:
 			OUT("[Channel] ");
@@ -151,7 +154,8 @@ render_search(struct search_response *r)
 		}
 		if (v->viewcount[0]) {
 			OUT("iViews:         ");
-			printnumsep(v->viewcount);
+			if (!printnumsep(v->viewcount))
+				OUT("0");
 			printf("\t%s\t%s\t%s\r\n", "", host, port);
 		}
 	}
@@ -159,6 +163,7 @@ render_search(struct search_response *r)
 
 	return 0;
 }
+
 int
 render_video(struct video_response *r)
 {
@@ -180,10 +185,13 @@ render_video(struct video_response *r)
         OUTTEXT(r->id);
 	printf("\t%s\t%s\r\n", host, port);
 
-	OUT("iURL:       ");
+	OUT("hURL:       ");
 	OUT("https://www.youtube.com/embed/");
         OUTTEXT(r->id);
-	printf("\t%s\t%s\t%s\r\n", "", host, port);
+	OUT("\tURL:");
+	OUT("https://www.youtube.com/embed/");
+        OUTTEXT(r->id);
+	printf("\t%s\t%s\r\n", host, port);
 
 	if (r->lengthseconds > 0) {
 		OUT("iLength:    ");
@@ -192,6 +200,17 @@ render_video(struct video_response *r)
 		printf("\t%s\t%s\t%s\r\n", "", host, port);
 	}
 
+	/* show playability state and reason: for example when it is a members-only video */
+	if (r->playabilityreason[0]) {
+		OUT("iStatus:    ");
+		if (r->playabilitystatus[0]) {
+			OUTTEXT(r->playabilitystatus);
+			OUTTEXT(": ");
+		}
+		OUTTEXT(r->playabilityreason);
+		printf("\t%s\t%s\t%s\r\n", "", host, port);
+	}
+
 	OUT("hThumbnail: https://i.ytimg.com/vi/");
 	OUTTEXT(r->id);
 	OUT("/hqdefault.jpg\tURL:https://i.ytimg.com/vi/");
@@ -212,7 +231,8 @@ render_video(struct video_response *r)
 
 	OUT("iViews:     ");
 	snprintf(buf, sizeof(buf), "%ld", r->viewcount);
-	printnumsep(buf);
+	if (!printnumsep(buf))
+		OUT("0");
 	printf("\t%s\t%s\t%s\r\n", "", host, port);
 
 	if (r->publishdate[0]) {
@@ -276,7 +296,9 @@ main(void)
 		host = p;
 	if ((p = getenv("SERVER_PORT")))
 		port = p;
-	if ((p = getenv("PATH_INFO")))
+	if ((p = getenv("PATH_TRANSLATED")))
+		requestpath = p;
+	else if ((p = getenv("PATH_INFO"))) /* fallback to PATH_INFO */
 		requestpath = p;
 	if ((p = getenv("QUERY_STRING")))
 		querystring = p;
