@@ -43,8 +43,6 @@ request_video(const char *videoid)
 	if (r < 0 || (size_t)r >= sizeof(path))
 		return NULL;
 
-//	return readfile("/tmp/data"); // DEBUG
-
 	return youtube_request(path);
 }
 
@@ -147,6 +145,12 @@ extractjson_video(const char *s, const char **start, const char **end)
 	return 0;
 }
 
+static int
+isrenderername(const char *name)
+{
+	return !strcmp(name, "videoRenderer");
+}
+
 static void
 processnode_search(struct json_node *nodes, size_t depth, const char *value, size_t valuelen,
 	void *pp)
@@ -161,7 +165,7 @@ processnode_search(struct json_node *nodes, size_t depth, const char *value, siz
 	   (items|contents)[].videoRenderer objects */
 	if (depth >= 3 &&
 	    nodes[depth - 1].type == JSON_TYPE_OBJECT &&
-	    !strcmp(nodes[depth - 1].name, "videoRenderer")) {
+	    isrenderername(nodes[depth - 1].name)) {
 		r->nitems++;
 		return;
 	}
@@ -172,7 +176,7 @@ processnode_search(struct json_node *nodes, size_t depth, const char *value, siz
 
 	if (depth >= 4 &&
 	    nodes[depth - 1].type == JSON_TYPE_STRING &&
-	    !strcmp(nodes[depth - 2].name, "videoRenderer") &&
+	    isrenderername(nodes[depth - 2].name) &&
 	    !strcmp(nodes[depth - 1].name, "videoId")) {
 		strlcpy(item->id, value, sizeof(item->id));
 	}
@@ -183,7 +187,7 @@ processnode_search(struct json_node *nodes, size_t depth, const char *value, siz
 	    nodes[depth - 3].type == JSON_TYPE_ARRAY &&
 	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 1].type == JSON_TYPE_STRING &&
-	    !strcmp(nodes[depth - 5].name, "videoRenderer") &&
+	    isrenderername(nodes[depth - 5].name) &&
 	    !strcmp(nodes[depth - 4].name, "title") &&
 	    !strcmp(nodes[depth - 3].name, "runs") &&
 	    !strcmp(nodes[depth - 1].name, "text") &&
@@ -200,7 +204,7 @@ processnode_search(struct json_node *nodes, size_t depth, const char *value, siz
 	    nodes[depth - 3].type == JSON_TYPE_ARRAY &&
 	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 1].type == JSON_TYPE_STRING &&
-	    !strcmp(nodes[depth - 7].name, "videoRenderer") &&
+	    isrenderername(nodes[depth - 7].name) &&
 	    !strcmp(nodes[depth - 6].name, "detailedMetadataSnippets") &&
 	    !strcmp(nodes[depth - 4].name, "snippetText") &&
 	    !strcmp(nodes[depth - 3].name, "runs") &&
@@ -215,19 +219,34 @@ processnode_search(struct json_node *nodes, size_t depth, const char *value, siz
 	    nodes[depth - 3].type == JSON_TYPE_ARRAY &&
 	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 1].type == JSON_TYPE_STRING &&
-	    !strcmp(nodes[depth - 5].name, "videoRenderer") &&
+	    isrenderername(nodes[depth - 5].name) &&
 	    !strcmp(nodes[depth - 4].name, "descriptionSnippet") &&
 	    !strcmp(nodes[depth - 3].name, "runs") &&
 	    !strcmp(nodes[depth - 1].name, "text")) {
 		strlcat(item->shortdescription, value, sizeof(item->shortdescription));
 	}
 
+	/* try to detect members/sponsor/subscription-only videos */
+	if (depth >= 7 &&
+	    nodes[depth - 5].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 4].type == JSON_TYPE_ARRAY &&
+	    nodes[depth - 3].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
+	    nodes[depth - 1].type == JSON_TYPE_STRING &&
+	    isrenderername(nodes[depth - 5].name) &&
+	    !strcmp(nodes[depth - 4].name, "badges") &&
+	    !strcmp(nodes[depth - 2].name, "metadataBadgeRenderer") &&
+	    !strcmp(nodes[depth - 1].name, "label")) {
+		if (strstr(value, "Members only"))
+			item->membersonly = 1;
+	}
+
 	if (depth >= 5 &&
 	    nodes[depth - 4].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 3].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 1].type == JSON_TYPE_STRING &&
-	    !strcmp(nodes[depth - 3].name, "videoRenderer") &&
+	    isrenderername(nodes[depth - 3].name) &&
 	    !strcmp(nodes[depth - 1].name, "simpleText")) {
 		if (!strcmp(nodes[depth - 2].name, "viewCountText") &&
 		    !item->viewcount[0]) {
@@ -250,7 +269,7 @@ processnode_search(struct json_node *nodes, size_t depth, const char *value, siz
 	    nodes[depth - 3].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 1].type == JSON_TYPE_STRING &&
-	    !strcmp(nodes[depth - 7].name, "videoRenderer") &&
+	    isrenderername(nodes[depth - 7].name) &&
 	    !strcmp(nodes[depth - 6].name, "longBylineText") &&
 	    !strcmp(nodes[depth - 5].name, "runs") &&
 	    !strcmp(nodes[depth - 3].name, "navigationEndpoint") &&
@@ -267,7 +286,7 @@ processnode_search(struct json_node *nodes, size_t depth, const char *value, siz
 	    nodes[depth - 3].type == JSON_TYPE_ARRAY &&
 	    nodes[depth - 2].type == JSON_TYPE_OBJECT &&
 	    nodes[depth - 1].type == JSON_TYPE_STRING &&
-	    !strcmp(nodes[depth - 5].name, "videoRenderer") &&
+	    isrenderername(nodes[depth - 5].name) &&
 	    !strcmp(nodes[depth - 4].name, "longBylineText") &&
 	    !strcmp(nodes[depth - 3].name, "runs")) {
 		if (!strcmp(nodes[depth - 1].name, "text") &&
@@ -281,7 +300,9 @@ static struct search_response *
 parse_search_response(const char *data)
 {
 	struct search_response *r;
+	struct item *item;
 	const char *s, *start, *end;
+	size_t i, len;
 	int ret;
 
 	if (!(s = strstr(data, "\r\n\r\n")))
@@ -289,8 +310,6 @@ parse_search_response(const char *data)
 	/* skip header */
 	s += strlen("\r\n\r\n");
 
-//	s = data; // DEBUG
-
 	if (!(r = calloc(1, sizeof(*r))))
 		return NULL;
 
@@ -304,6 +323,22 @@ parse_search_response(const char *data)
 		free(r);
 		return NULL;
 	}
+
+	/* workaround: sometimes playlists or topics are listed as channels, filter
+	   these topic/playlist links away because they won't work for channel videos. The
+	   JSON response would have to be parsed in a different way than channels. */
+	for (i = 0; i < r->nitems; i++) {
+		item = &(r->items[i]);
+		len = strlen(item->channeltitle);
+
+		if (len > sizeof(" - Topic") &&
+		    !strcmp(item->channeltitle + len - sizeof(" - Topic") + 1, " - Topic")) {
+			/* reset information that doesn't work for topics */
+			item->channelid[0] = '\0';
+			item->viewcount[0] = '\0';
+		}
+	}
+
 	return r;
 }
 
@@ -315,6 +350,21 @@ processnode_video(struct json_node *nodes, size_t depth, const char *value, size
 	struct video_format *f;
 
 	if (depth > 1) {
+		/* playability status: could be unplayable / members-only video */
+		if (nodes[0].type == JSON_TYPE_OBJECT &&
+		    !strcmp(nodes[1].name, "playabilityStatus")) { /* example: "UNPLAYABLE" */
+			if (depth == 3 &&
+			    nodes[2].type == JSON_TYPE_STRING &&
+			    !strcmp(nodes[2].name, "status")) {
+				strlcpy(r->playabilitystatus, value, sizeof(r->playabilitystatus));
+			}
+			if (depth == 3 &&
+			    nodes[2].type == JSON_TYPE_STRING &&
+			    !strcmp(nodes[2].name, "reason")) {
+				strlcpy(r->playabilityreason, value, sizeof(r->playabilityreason));
+			}
+		}
+
 		if (nodes[0].type == JSON_TYPE_OBJECT &&
 		    !strcmp(nodes[1].name, "streamingData")) {
 			if (depth == 2 &&
@@ -438,8 +488,6 @@ parse_video_response(const char *data)
 	/* skip header */
 	s += strlen("\r\n\r\n");
 
-//	s = data; // DEBUG
-
 	if (!(r = calloc(1, sizeof(*r))))
 		return NULL;
 
